@@ -3,5 +3,7 @@ from tf_geometric.datasets.ppi import PPIDataset
 from tf_geometric.datasets.tu import TUDataset
 from tf_geometric.datasets.planetoid import PlanetoidDataset, CoraDataset, CiteseerDataset, PubmedDataset, \
     SupervisedCoraDataset, SupervisedCiteseerDataset, SupervisedPubmedDataset
+from tf_geometric.datasets.blog_catalog import MultiLabelBlogCatalogDataset
 from tf_geometric.datasets.reddit import TransductiveRedditDataset, InductiveRedditDataset
 from tf_geometric.datasets.ogb import OGBNodePropPredDataset
+from tf_geometric.datasets.model_net import ModelNet10Dataset, ModelNet40Dataset
